# The Room environments (compatible with gymnasium)

[![DOI](https://zenodo.org/badge/614376641.svg)](https://zenodo.org/doi/10.5281/zenodo.10876436)
[![PyPI
version](https://badge.fury.io/py/room-env.svg)](https://badge.fury.io/py/room-env)

At the moment, there are three versions of the Room environments.

## README for each version

- [RoomEnv-v0](./README-v0.md)
- [RoomEnv-v1](./README-v1.md)
- [RoomEnv-v2](./README-v2.md)
- [RoomEnv-v3](./README-v3.md)

## List of academic papers that use the Rooms environments

- ["A Machine With Human-Like Memory Systems"](https://arxiv.org/abs/2204.01611)
- ["A Machine with Short-Term, Episodic, and Semantic Memory
  Systems"](https://arxiv.org/abs/2212.02098)
- ["Leveraging Knowledge Graph-Based Human-Like Memory Systems to Solve Partially Observable Markov Decision Processes"](https://arxiv.org/abs/2408.05861)

## pdoc documentation

Click on [this link](https://humemai.github.io/room-env) to see the HTML rendered
docstrings
